#!/bin/sh

#-------- OpenHAB demo configuration files installer script
#-------- package based on work from pcloadletter.co.uk

DOWNLOAD_FILE="distribution-1.4.0-demo-configuration.zip"
DOWNLOAD_PATH="https://github.com/openhab/openhab/releases/download/v1.4.0"
EXTRACTED_FOLDER="OpenHAB-demo-configuration-1.4.0"
DOWNLOAD_URL="${DOWNLOAD_PATH}/${DOWNLOAD_FILE}"
DAEMON_USER="openhab"
INSTALL_FILES="${DOWNLOAD_URL}"
source /etc/profile
TEMP_FOLDER="`find / -maxdepth 2 -name '@tmp' | head -n 1`"
PRIMARY_VOLUME="/`echo $TEMP_FOLDER | cut -f2 -d'/'`"


preinst ()
{
  cd ${TEMP_FOLDER}
  for WGET_URL in ${INSTALL_FILES}
  do
    WGET_FILENAME="`echo ${WGET_URL} | sed -r "s%^.*/(.*)%\1%"`"
    [ -f ${TEMP_FOLDER}/${WGET_FILENAME} ] && rm ${TEMP_FOLDER}/${WGET_FILENAME}
    wget --no-check-certificate --output-document=${WGET_FILENAME} ${WGET_URL}
    if [[ $? != 0 ]]; then
      if [ -d ${PUBLIC_FOLDER} ] && [ -f ${PUBLIC_FOLDER}/${DOWNLOAD_FILE} ]; then
        cp ${PUBLIC_FOLDER}/${DOWNLOAD_FILE} ${TEMP_FOLDER}
      else     
        echo "There was a problem downloading ${WGET_FILENAME} from the official download link, "
        echo "which was \"${WGET_URL}\" "
        echo "Alternatively, you may download this file manually and place it in the 'public' shared folder. "
        exit 1
      fi
    fi
  done
  
  exit 0
}


postinst ()
{
  #extract main archive
  cd ${TEMP_FOLDER}
  unzip ${TEMP_FOLDER}/${DOWNLOAD_FILE} -d ${EXTRACTED_FOLDER} && rm ${TEMP_FOLDER}/${DOWNLOAD_FILE}
  cp -r ${TEMP_FOLDER}/${EXTRACTED_FOLDER}/addons/* /var/packages/OpenHAB/target/addons/
  cp -r ${TEMP_FOLDER}/${EXTRACTED_FOLDER}/configurations/* /var/packages/OpenHAB/target/configurations/
# replace demo.rules as TTS is not working with slow cpu's
  cp ${SYNOPKG_PKGDEST}/demo.rules /var/packages/OpenHAB/target/configurations/rules/
  rmdir ${TEMP_FOLDER}/${EXTRACTED_FOLDER}

# change permission of demofiles: user of files: openhab with wx permissions
  chown ${DAEMON_USER} ${TEMP_FOLDER}/${EXTRACTED_FOLDER}/configurations/items/demo.items
  chown ${DAEMON_USER} ${TEMP_FOLDER}/${EXTRACTED_FOLDER}/configurations/rules/demo.rules
  chown ${DAEMON_USER} ${TEMP_FOLDER}/${EXTRACTED_FOLDER}/configurations/scripts/demo.script
  chown ${DAEMON_USER} ${TEMP_FOLDER}/${EXTRACTED_FOLDER}/configurations/sitemaps/demo.sitemap
  chown ${DAEMON_USER} ${TEMP_FOLDER}/${EXTRACTED_FOLDER}/configurations/persistence/logging.persist
  chown ${DAEMON_USER} ${TEMP_FOLDER}/${EXTRACTED_FOLDER}/configurations/persistence/db4o.persist
  chown ${DAEMON_USER} ${TEMP_FOLDER}/${EXTRACTED_FOLDER}/configurations/persistence/exec.persist
  chown ${DAEMON_USER} ${TEMP_FOLDER}/${EXTRACTED_FOLDER}/configurations/persistence/rrd4j.persist
  
  chmod u+x ${TEMP_FOLDER}/${EXTRACTED_FOLDER}/configurations/items/demo.items
  chmod u+x ${TEMP_FOLDER}/${EXTRACTED_FOLDER}/configurations/rules/demo.rules
  chmod u+x ${TEMP_FOLDER}/${EXTRACTED_FOLDER}/configurations/scripts/demo.script
  chmod u+x ${TEMP_FOLDER}/${EXTRACTED_FOLDER}/configurations/sitemaps/demo.sitemap
  chmod u+x ${TEMP_FOLDER}/${EXTRACTED_FOLDER}/configurations/persistence/logging.persist
  chmod u+x ${TEMP_FOLDER}/${EXTRACTED_FOLDER}/configurations/persistence/db4o.persist
  chmod u+x ${TEMP_FOLDER}/${EXTRACTED_FOLDER}/configurations/persistence/exec.persist
  chmod u+x ${TEMP_FOLDER}/${EXTRACTED_FOLDER}/configurations/persistence/rrd4j.persist
                  

  exit 0
}


preuninst ()
{
  #nothing to do
  exit 0
}


postuninst ()
{
  #remove addons
  rm /var/packages/OpenHAB/target/addons/org.openhab.persistence.rrd4j-1.4.0.jar
  rm /var/packages/OpenHAB/target/addons/org.openhab.persistence.logging-1.4.0.jar
  rm /var/packages/OpenHAB/target/addons/org.openhab.persistence.exec-1.4.0.jar
  rm /var/packages/OpenHAB/target/addons/org.openhab.io.multimedia.tts.freetts-1.4.0.jar
  rm /var/packages/OpenHAB/target/addons/org.openhab.binding.ntp-1.4.0.jar
  rm /var/packages/OpenHAB/target/addons/org.openhab.binding.http-1.4.0.jar
  # remove demo configuration
  rm /var/packages/OpenHAB/target/configurations/items/demo.items
  rm /var/packages/OpenHAB/target/configurations/rules/demo.rules
  rm /var/packages/OpenHAB/target/configurations/scripts/demo.script
  rm /var/packages/OpenHAB/target/configurations/sitemaps/demo.sitemap
#  rm /var/packages/OpenHAB/target/configurations/persistence/logging.persist
#  rm /var/packages/OpenHAB/target/configurations/persistence/db4o.persist
#  rm /var/packages/OpenHAB/target/configurations/persistence/exec.persist
#  rm /var/packages/OpenHAB/target/configurations/persistence/rrd4j.persist
  exit 0
}
